==> v4_navigation_engine-0.1.30.tar.gz: ios/Classes/NavigationV4/View/MyNavigationView+MGLMapViewDelegate.swift <==
//
//  MyNavigationView+MGLMapViewDelegate.swift
//  NavigationUI
//
//  Created by hassine othmane on 3/30/20.
//  Copyright © 2020 com.mile. All rights reserved.
//

import MapboxNavigation

import CoreLocation
import MapboxDirections

extension MyNavigationView : MGLMapViewDelegate
{
    
    public func mapView(_ mapView: MGLMapView, regionWillChangeWith reason: MGLCameraChangeReason, animated: Bool) {
        if reason != .programmatic && reason != .transitionCancelled && reason.rawValue != 65537 
        {
            center_btn.isHidden = false
        }
    }
    
    public func mapViewUserLocationAnchorPoint(_ mapView: MGLMapView) -> CGPoint {
        return CGPoint.init(x: self.mapView_map.frame.width/2, y: self.mapView_map.frame.height-100)
    }
    
    public func mapView(_ mapView: MGLMapView, annotationCanShowCallout annotation: MGLAnnotation) -> Bool {
        if !(annotation is MGLUserLocation) && !(annotation is BloquantPointAnnotation)  && !(annotation is DirectionalPointAnnotation) 
        {
            if let myCustomPointAnnotation = annotation as? MyCustomPointAnnotation
            {
                if myCustomPointAnnotation.category == .sponsor
                {
                   
                    return false
                }
               
            }
            
        } else if   (annotation is BloquantPointAnnotation)  || (annotation is DirectionalPointAnnotation)
        {
          
        }
        return false
    }
    
    
    public func mapViewDidFinishLoadingMap(_ mapView: MGLMapView) {
        if let coordinates = routeCoordinates , coordinates.count > 0
        {
            if routeInformation?.isStartingPointStatic == false
            {
                routeCoordinates = MyUtils.changeBeginningOfSmartRunWithnearestPoint(coordinates, positionGPS: LocationService.shared.getCurrentLocation())
            }
            if let firstPoint = routeCoordinates?.first
            {
                
                DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+0.5) {
                    
                    if let route = self.routeInformation
                    {
                        if route.sponsors.count > 0
                        {
                            var firstSponsor: Bool = true
                            var annonceSponsor: String = self.languageRessource.annonceSponsor
                            for sponsor in route.sponsors {
                                if !firstSponsor {
                                    annonceSponsor += self.languageRessource.andSponsor
                                }
                                annonceSponsor += sponsor.vocal ?? sponsor.name ?? ""
                                firstSponsor = false
                            }
                            annonceSponsor += self.languageRessource.moreSponsorInformations
                            
                            PlayerManager.shared.playSynt(description: annonceSponsor)
                            if self.routeInformation!.isStartingPointStatic == true
                            {
                                PlayerManager.shared.playSynt(description: self.languageRessource.startNavigationToStaticStartingPoint)
                                DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+14) {
                                    self.presenter.calculateRoute(startPoint:firstPoint, locale: self.languageAndCountry,measurementSystem: self.measurementSystem, objectFor: self)
                                }
                            }
                            else
                            {
                                PlayerManager.shared.playSynt(description: self.languageRessource.startNavigationToRoute)
                                DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+6) {
                                    self.presenter.calculateRoute(startPoint:firstPoint, locale: self.languageAndCountry,measurementSystem: self.measurementSystem, objectFor: self)
                                }
                            }
                            
                            
                        }
                        else
                        {
                            if self.routeInformation!.isStartingPointStatic == true
                            {
                                
                                PlayerManager.shared.playSynt(description: self.languageRessource.startNavigationToStaticStartingPoint)
                                DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+7) {
                                    self.presenter.calculateRoute(startPoint:firstPoint, locale: self.languageAndCountry,measurementSystem: self.measurementSystem, objectFor: self)
                                }
                            }
                            else
                            {
                                
                                PlayerManager.shared.playSynt(description: self.languageRessource.startNavigationToRoute)
                                DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+2) {
                                    self.presenter.calculateRoute(startPoint:firstPoint, locale: self.languageAndCountry,measurementSystem: self.measurementSystem, objectFor: self)
                                }
                            }
                        }
                    }
                    else
                    {
                        if self.routeInformation!.isStartingPointStatic == true
                        {
                            
                        }
                        else
                        {
                            PlayerManager.shared.playSynt(description: self.languageRessource.startNavigationToStaticStartingPoint)
                            DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+7) {
                                self.presenter.calculateRoute(startPoint:firstPoint, locale: self.languageAndCountry,measurementSystem: self.measurementSystem, objectFor: self)
                            }
                            
                        }
                    }
                    
                }
            }
        }
    }
    
    public func mapView(_ mapView: MGLMapView, viewFor annotation: MGLAnnotation) -> MGLAnnotationView? {
        if annotation is MGLUserLocation && mapView.userLocation != nil {
            return CustomUserLocationAnnotationView()
        }
        if let castAnnotation = annotation as? MyCustomPointAnnotation {
            if (castAnnotation.willUseImage) {
                return nil
            }
        }
        // Assign a reuse identifier to be used by both of the annotation views, taking advantage of their similarities.
        let reuseIdentifier = "reusableDotView"
        // For better performance, always try to reuse existing annotations.
        let annotationView = mapView.dequeueReusableAnnotationView(withIdentifier: reuseIdentifier)
        return annotationView
    }
    
    public func mapView(_ mapView: MGLMapView, imageFor annotation: MGLAnnotation) -> MGLAnnotationImage? {
        if let annotationFlag = annotation as? MyCustomFlagPointAnnotation {
            if annotationFlag.isStartFlag
            {
                let annotationImage = MGLAnnotationImage(image:  Bundle.assets.image(named: "start_flag")!, reuseIdentifier: "start_flag")
                return annotationImage
            }
            else
            {
                return MGLAnnotationImage.init(image: Bundle.assets.image(named: "finishflag_night")!, reuseIdentifier: "finishflag_night")
            }
        }
        if let castAnnotation = annotation as? MyCustomPointAnnotation {
            if (!castAnnotation.willUseImage) {
                return nil
            }
            else
            {
                switch castAnnotation.category {
                case .undefined:
                    // For better performance, always try to reuse existing annotations.
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_undefined")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "undefined")!, reuseIdentifier: "pin_undefined")
                    }
                    return annotationImage
                case .culture:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_culture")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image:Bundle.assets.image(named: "culture")!, reuseIdentifier: "pin_culture")
                    }
                    return annotationImage
                case .eau:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_eau")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "water")!, reuseIdentifier: "pin_eau")
                    }
                    return annotationImage
                case .marchand:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_marchand")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "shop")!, reuseIdentifier: "pin_marchand")
                    }
                    return annotationImage
                case .monument:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_monument")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "culture")!, reuseIdentifier: "pin_monument")
                    }
                    return annotationImage
                case .nature:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_nature")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "nature")!, reuseIdentifier: "pin_nature")
                    }
                    return annotationImage
                case .religion:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_religion")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "religion")!, reuseIdentifier: "pin_religion")
                    }
                    return annotationImage
                case .ruePlaceQuartier:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_quartier")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "neighbourhood")!, reuseIdentifier: "pin_quartier")
                    }
                    return annotationImage
                case .sport:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_quartier")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "workout")!, reuseIdentifier: "pin_quartier")
                    }
                    return annotationImage
                case .theme:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_thematique")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image:Bundle.assets.image(named: "shop")!, reuseIdentifier: "pin_thematique")
                        
                    }
                    return annotationImage
                case .sponsor:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_sponsor")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image:Bundle.assets.image(named: "sponsor")!, reuseIdentifier: "pin_sponsor")
                        
                    }
                    return annotationImage
                    
                default:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_undefined")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "undefined")!, reuseIdentifier: "pin_undefined")
                    }
                    return annotationImage
                }
            }
        }
        // For better performance, always try to reuse existing annotations.
        var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "poi")
        
        // If there is no reusable annotation image available, initialize a new one.
        if(annotationImage == nil) {
            annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "undefined")!, reuseIdentifier: "poi")
        }
        return annotationImage
    }
    
    
    public func mapView(_ mapView: MGLMapView, fillColorForPolygonAnnotation annotation: MGLPolygon) -> UIColor {
        if annotation is  DirectionalPointPolygon
        {
            return UIColor.green
        }
        else if annotation is BloquantPointPolygon
        {
            return UIColor.red
        }
        else if annotation is SecondPositionPointPolygon
        {
            return UIColor.blue
        }
        else
        {
            return Style.shared.primaryColor
        }
        
    }
    
}

==> v4_navigation_engine-0.1.31.tar.gz: ios/Classes/NavigationV4/View/MyNavigationView+MGLMapViewDelegate.swift <==
//
//  MyNavigationView+MGLMapViewDelegate.swift
//  NavigationUI
//
//  Created by hassine othmane on 3/30/20.
//  Copyright © 2020 com.mile. All rights reserved.
//

import MapboxNavigation

import CoreLocation
import MapboxDirections

extension MyNavigationView : MGLMapViewDelegate
{
    
    public func mapView(_ mapView: MGLMapView, regionWillChangeWith reason: MGLCameraChangeReason, animated: Bool) {
        if reason != .programmatic && reason != .transitionCancelled && reason.rawValue != 65537 
        {
            center_btn.isHidden = false
        }
    }
    
    public func mapViewUserLocationAnchorPoint(_ mapView: MGLMapView) -> CGPoint {
        return CGPoint.init(x: self.mapView_map.frame.width/2, y: self.mapView_map.frame.height-100)
    }
    
    public func mapView(_ mapView: MGLMapView, annotationCanShowCallout annotation: MGLAnnotation) -> Bool {
        if !(annotation is MGLUserLocation) && !(annotation is BloquantPointAnnotation)  && !(annotation is DirectionalPointAnnotation) 
        {
            if let myCustomPointAnnotation = annotation as? MyCustomPointAnnotation
            {
                if myCustomPointAnnotation.category == .sponsor
                {
                   
                    return false
                }
               
            }
            
        } else if   (annotation is BloquantPointAnnotation)  || (annotation is DirectionalPointAnnotation)
        {
          
        }
        return false
    }
    
    
    public func mapViewDidFinishLoadingMap(_ mapView: MGLMapView) {
        if let coordinates = routeCoordinates , coordinates.count > 0 {
            if routeInformation?.isStartingPointStatic == false {
                routeCoordinates = MyUtils.changeBeginningOfSmartRunWithnearestPoint(coordinates, positionGPS: LocationService.shared.getCurrentLocation())
            }

            if let firstPoint = routeCoordinates?.first {
                
                DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+0.5) {

                    self.flutterMapViewDidFinishLoadingMap()
                    if let route = self.routeInformation {
                        if route.sponsors.count > 0 {
                            var firstSponsor: Bool = true
                            var annonceSponsor: String = self.languageRessource.annonceSponsor
                            for sponsor in route.sponsors {
                                if !firstSponsor {
                                    annonceSponsor += self.languageRessource.andSponsor
                                }
                                annonceSponsor += sponsor.vocal ?? sponsor.name ?? ""
                                firstSponsor = false
                            }
                            annonceSponsor += self.languageRessource.moreSponsorInformations
                            
                            PlayerManager.shared.playSynt(description: annonceSponsor)
                            if self.routeInformation!.isStartingPointStatic == true {
                                var sentence = self.languageRessource.startNavigationToStaticStartingPoint
                                if self.whiteLabel?.isWhiteLabel ?? false {
                                    sentence = (self.whiteLabel?.beginInstruction ?? "") + " " + self.languageRessource.startNavigationToStaticStartingPoint
                                }
                                PlayerManager.shared.playSynt(description: sentence)
                                DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+14) {
                                    self.presenter.calculateRoute(startPoint:firstPoint, locale: self.languageAndCountry,measurementSystem: self.measurementSystem, objectFor: self)
                                }
                            } else {
                                //Add custom begin instruction for white label
                                var sentence = self.languageRessource.startNavigationToRoute
                                if self.whiteLabel?.isWhiteLabel ?? false {
                                    sentence = (self.whiteLabel?.beginInstruction ?? "") + " " + self.languageRessource.startNavigationToRoute
                                }
                                PlayerManager.shared.playSynt(description: sentence)
                                DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+6) {
                                    self.presenter.calculateRoute(startPoint:firstPoint, locale: self.languageAndCountry,measurementSystem: self.measurementSystem, objectFor: self)
                                }
                            }
                        } else {
                            if self.routeInformation!.isStartingPointStatic == true {
                                var sentence = self.languageRessource.startNavigationToStaticStartingPoint
                                if self.whiteLabel?.isWhiteLabel ?? false {
                                    sentence = (self.whiteLabel?.beginInstruction ?? "") + " " + self.languageRessource.startNavigationToStaticStartingPoint
                                }
                                PlayerManager.shared.playSynt(description: sentence)
                                DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+7) {
                                    self.presenter.calculateRoute(startPoint:firstPoint, locale: self.languageAndCountry,measurementSystem: self.measurementSystem, objectFor: self)
                                }
                            } else {
                                var sentence = self.languageRessource.startNavigationToRoute
                                if self.whiteLabel?.isWhiteLabel ?? false {
                                    sentence = (self.whiteLabel?.beginInstruction ?? "") + " " + self.languageRessource.startNavigationToRoute
                                }
                                PlayerManager.shared.playSynt(description: sentence)
                                DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+2) {
                                    self.presenter.calculateRoute(startPoint:firstPoint, locale: self.languageAndCountry,measurementSystem: self.measurementSystem, objectFor: self)
                                }
                            }
                        }
                    } else {
                        if self.routeInformation!.isStartingPointStatic == true {
                            
                        } else {
                            var sentence = self.languageRessource.startNavigationToStaticStartingPoint
                            if self.whiteLabel?.isWhiteLabel ?? false {
                                sentence = (self.whiteLabel?.beginInstruction ?? "") + " " + self.languageRessource.startNavigationToStaticStartingPoint;
                            }
                            PlayerManager.shared.playSynt(description: sentence)
                            DispatchQueue.main.asyncAfter(deadline: DispatchTime.now()+7) {
                                self.presenter.calculateRoute(startPoint:firstPoint, locale: self.languageAndCountry,measurementSystem: self.measurementSystem, objectFor: self)
                            }
                            
                        }
                    }
                    
                }
            }
        }
    }
    
    public func mapView(_ mapView: MGLMapView, viewFor annotation: MGLAnnotation) -> MGLAnnotationView? {
        if annotation is MGLUserLocation && mapView.userLocation != nil {
            return CustomUserLocationAnnotationView()
        }
        if let castAnnotation = annotation as? MyCustomPointAnnotation {
            if (castAnnotation.willUseImage) {
                return nil
            }
        }
        // Assign a reuse identifier to be used by both of the annotation views, taking advantage of their similarities.
        let reuseIdentifier = "reusableDotView"
        // For better performance, always try to reuse existing annotations.
        let annotationView = mapView.dequeueReusableAnnotationView(withIdentifier: reuseIdentifier)
        return annotationView
    }
    
    public func mapView(_ mapView: MGLMapView, imageFor annotation: MGLAnnotation) -> MGLAnnotationImage? {
        if let annotationFlag = annotation as? MyCustomFlagPointAnnotation {
            if annotationFlag.isStartFlag
            {
                let annotationImage = MGLAnnotationImage(image:  Bundle.assets.image(named: "start_flag")!, reuseIdentifier: "start_flag")
                return annotationImage
            }
            else
            {
                return MGLAnnotationImage.init(image: Bundle.assets.image(named: "finishflag_night")!, reuseIdentifier: "finishflag_night")
            }
        }
        if let castAnnotation = annotation as? MyCustomPointAnnotation {
            if (!castAnnotation.willUseImage) {
                return nil
            }
            else
            {
                switch castAnnotation.category {
                case .undefined:
                    // For better performance, always try to reuse existing annotations.
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_undefined")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "undefined")!, reuseIdentifier: "pin_undefined")
                    }
                    return annotationImage
                case .culture:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_culture")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image:Bundle.assets.image(named: "culture")!, reuseIdentifier: "pin_culture")
                    }
                    return annotationImage
                case .eau:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_eau")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "water")!, reuseIdentifier: "pin_eau")
                    }
                    return annotationImage
                case .marchand:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_marchand")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "shop")!, reuseIdentifier: "pin_marchand")
                    }
                    return annotationImage
                case .monument:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_monument")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "culture")!, reuseIdentifier: "pin_monument")
                    }
                    return annotationImage
                case .nature:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_nature")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "nature")!, reuseIdentifier: "pin_nature")
                    }
                    return annotationImage
                case .religion:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_religion")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "religion")!, reuseIdentifier: "pin_religion")
                    }
                    return annotationImage
                case .ruePlaceQuartier:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_quartier")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "neighbourhood")!, reuseIdentifier: "pin_quartier")
                    }
                    return annotationImage
                case .sport:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_quartier")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "workout")!, reuseIdentifier: "pin_quartier")
                    }
                    return annotationImage
                case .theme:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_thematique")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image:Bundle.assets.image(named: "shop")!, reuseIdentifier: "pin_thematique")
                        
                    }
                    return annotationImage
                case .sponsor:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_sponsor")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image:Bundle.assets.image(named: "sponsor")!, reuseIdentifier: "pin_sponsor")
                        
                    }
                    return annotationImage
                    
                default:
                    var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "pin_undefined")
                    if(annotationImage == nil) {
                        annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "undefined")!, reuseIdentifier: "pin_undefined")
                    }
                    return annotationImage
                }
            }
        }
        // For better performance, always try to reuse existing annotations.
        var annotationImage = mapView.dequeueReusableAnnotationImage(withIdentifier: "poi")
        
        // If there is no reusable annotation image available, initialize a new one.
        if(annotationImage == nil) {
            annotationImage = MGLAnnotationImage(image: Bundle.assets.image(named: "undefined")!, reuseIdentifier: "poi")
        }
        return annotationImage
    }
    
    
    public func mapView(_ mapView: MGLMapView, fillColorForPolygonAnnotation annotation: MGLPolygon) -> UIColor {
        if annotation is  DirectionalPointPolygon
        {
            return UIColor.green
        }
        else if annotation is BloquantPointPolygon
        {
            return UIColor.red
        }
        else if annotation is SecondPositionPointPolygon
        {
            return UIColor.blue
        }
        else
        {
            return Style.shared.primaryColor
        }
        
    }
    
}
